==> deets_0.0.5.orig.tar.gz: deets-0.0.5/debian.lua <==
-- deets: debian.lua
-- Copyright (C) 2009, 2010  Clint Adams

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
--

require("dpkg")
require("resource")

local ipairs = ipairs
local dpkg = dpkg
local print = print -- remove this in new phase
local register_resource = register_resource

module("debian")

function iscompliant(pkg, gota)
  local desiredstatus = gota.ensure
  local status = dpkg.status(pkg)

  if (desiredstatus == "installed") then
     if (status == "installed") then
        return true
     else
        return false
     end
  elseif (desiredstatus == "purged") then
     if (status == "not-installed") then
        return true
     else
        return false
     end
  elseif (desiredstatus == "removed") then
     if (status == "not-installed" or status == "config-files") then
        return true
     else
        return false
     end
  end

  return false
end

function rectify(pkg, gota)
  local status = gota.ensure
  if (status == "installed") then
	return "aptitude install "..pkg
  elseif (status == "removed") then
	return "aptitude remove "..pkg
  elseif (status == "purged") then
	return "dpkg -P "..pkg
  end
end

function package(pkglist, gotita)
  for _,pkg in ipairs(pkglist) do
    if (not register_resource("pkg", pkg, gotita)) then
        print("Registration error", pkg)
    end
  end
end

==> deets_0.0.6.orig.tar.gz: deets-0.0.6/debian.lua <==
-- deets: debian.lua
-- Copyright (C) 2009, 2010  Clint Adams

-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.

-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.

-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
--

require("dpkg")
require("resource")

local ipairs = ipairs
local dpkg = dpkg
local print = print -- remove this in new phase
local register_resource = register_resource

module("debian")

function iscompliant(pkg, gota)
  local desiredstatus = gota.ensure
  local status = dpkg.status(pkg)

  if (desiredstatus == "installed") then
     if (status == "installed") then
        return true
     else
        return false
     end
  elseif (desiredstatus == "purged") then
     if (status == "not-installed") then
        return true
     else
        return false
     end
  elseif (desiredstatus == "removed") then
     if (status == "not-installed" or status == "config-files") then
        return true
     else
        return false
     end
  end

  return false
end

function rectify(pkg, gota)
  local status = gota.ensure
  if (status == "installed") then
	return "aptitude -y install "..pkg
  elseif (status == "removed") then
	return "aptitude -y remove "..pkg
  elseif (status == "purged") then
	return "dpkg -P "..pkg
  end
end

function package(pkglist, gotita)
  for _,pkg in ipairs(pkglist) do
    if (not register_resource("pkg", pkg, gotita)) then
        print("Registration error", pkg)
    end
  end
end
